==> Spec-Recorder%20Ver.1.30.zip: Spec-Recorder Ver.1.30/main.py <==
# -*- coding: utf-8 -*-
# Spec_Recoeder Ver.1.21
# License = MIT
# Author = Yuta Minakawa
import subprocess
import datetime
import time
import os
import ConfigParser
import libhro

try:
	import Image
	import ImageDraw
	import ImageFont
except ImportError:
	print "Error! PIL is not installed!"
	time.sleep(1000)
	exit()

high_color = 0
mono_color = 0
del_ogg = 0
write_filename = 0
write_csv = 0
oggfilename = ""
pngfilename = ""
analyze = 0
conf = ConfigParser.SafeConfigParser()
conf.read("./sr.conf")
if conf.get("server", "server") == "on":
	subprocess.Popen(["python", "server.py"])
	print "HTTP server is working"
else:
	print "HTTP server is unavailable"
	
if conf.get("file", "del_ogg") == "on":
	del_ogg = 1
	print "del_ogg is available"
else:
	print "del_ogg is unavailable"
	
if conf.get("file", "write_filename") == "on":
	write_filename = 1
	print "filename will be written"
else:
	print "filename will not be written"

if conf.get("file", "write_csv") == "on":
	write_csv = 1
	print "CSV file will be saved"
	
if conf.get("analyze", "analyze") == "on":
	analyze = 1
	print "data will be analyzed"
	
if os.name == 'posix':
	print "OS = Linux,BSD,etc"
if os.name == 'nt':
	print "OS = Windows"
	
def write_cara(x,y,string,filename):#画像ファイルへのファイル名の書き込み
	font = ImageFont.truetype("/usr/share/fonts/truetype/takao-gothic/TakaoGothic.ttf", 15, encoding="utf-8")
	img = Image.open(filename)
	draw = ImageDraw.Draw(img)
	draw.text((x,y), string, font=font, fill=255)
	img.save(filename)

def rec(filename):#It is not used.
	output = subprocess.call()
	return(output)
	
def how_long(filename):#OGGファイルの長さを調べる
	output = subprocess.check_output(["sox", "--info", "-d", filename])
	#print output
	minute = output[4]
	ten_second = output[6]
	second = output[7]
	file_info = (minute , ten_second, second)
	return(file_info)
	
def write2freq_exec(content):#使わない
	f = open('text.txt', 'w')
	f.write(content)
	f.close()
	
def spec(filename):#スペクトラム描画
	#output = subprocess.call(['sox', filename + ".ogg", "-n", 'rate', '3k',"spectrogram" , "-X", "8", "-Y", "300", "-o", filename + ".png" ])
	wq = ''
	oggfilename = wq + "./ogg/" + filename + ".ogg" + wq
	pngfilename = wq + "./PNG/" + filename + ".png" + wq
	monofilename = wq + "./monoPNG/" + filename + ".png" + wq
	output = subprocess.Popen(['sox', oggfilename[:], "-n", 'rate', '3k',"spectrogram" , "-X", "8", "-Y", "300", "-z", "100", "-o", pngfilename[:] ])
	print filename +".png" + " was made"
	subprocess.Popen(['sox', "./ogg/" + filename + ".ogg", "-n", 'rate', '3k',"spectrogram" , "-X", "8", "-Y", "300", "-z", "100"])
	output = subprocess.Popen(['sox', oggfilename[:], "-n", 'rate', '3k',"spectrogram" , "-X", "8", "-Y", "300", "-z", "100", "-m", "-o", monofilename[:] ])
	return(output)

print "Spec_Recorder Ver.1.21"

now_minute = int(datetime.datetime.now().strftime("%M"))
now_hour = int(datetime.datetime.now().strftime("%H"))
now_month = int(datetime.datetime.now().strftime("%m"))
now_day = int(datetime.datetime.now().strftime("%d"))
now_year = int(datetime.datetime.now().strftime("%Y"))

if int(datetime.datetime.now().strftime("%M")) % 5 == 0:
	time.sleep(60)
subprocess.Popen(["python", "./freq_exec.py", "0"])
print "Executed freq_exec.py"

if conf.get("mail", "mail") == "on":
	subprocess.Popen(["python", "./freq_send_mail.py"])
	print "executed freq_send_mail.py"

while 1==1:#メインループ
	if int(datetime.datetime.now().strftime("%M")) % 5 == 0:
		start_year = str(datetime.datetime.now().strftime("%Y"))[2:]
		start_month = str(datetime.datetime.now().strftime("%m"))[:]
		if start_month < 10:
			start_month = "0" + str(datetime.datetime.now().strftime("%m"))[:]
		start_day = str(datetime.datetime.now().strftime("%d"))[:]
		if start_day < 10:
			start_day = "0" + str(datetime.datetime.now().strftime("%d"))[:]
		start_hour = str(datetime.datetime.now().strftime("%H"))[:]
		if start_hour < 10:
			start_hour = "0" + str(datetime.datetime.now().strftime("%H"))[:]
		start_minute = str(datetime.datetime.now().strftime("%M"))[:]
		if datetime.datetime.now().strftime("%M") < 10:
			start_minute = "0" + str(datetime.datetime.now().strftime("%M"))[:]
		filename = str(start_year)[:] + str(start_month)[:] + str(start_day)[:] + str(start_hour)[:] + str(start_minute)[:]
		print "Audio fileneme is " + filename + ".ogg"
		print "Waiting 5 minutes"
		time.sleep(60)
		for cnt in range(10000):
			if os.path.exists("./ogg/" + filename + ".ogg") == 1:
				print 1
				if how_long("./ogg/"+ filename + ".ogg")[0] == "5":
					break
			#print "Waiting for " + filename +".ogg."
			#oggファイルを待つ
			time.sleep(10)
		try:
			libhro.spec(filename, False)
		except:
			pass
		if conf.get("file", "del_ogg") == "on":
			try:
				if os.name == 'nt':
					subprocess.call(["del", "./ogg/" + filename + ".ogg"])
				else:
					subprocess.call(["rm", "./ogg/" + filename + ".ogg"])
			except:
				print "can't delete OGGfile"
		for cnt in range(200):
			if os.path.exists("./monoPNG/" + filename + ".png") == 1:
				print filename + ".png is exist"
				break
			print "Waiting for " + filename +".png"
			time.sleep(0.5)
		if conf.get("file", "write_filename") == "on":
			if os.path.exists("./PNG/" + filename + ".png") == 1:
				try:
					write_string = filename[:]
					write_cara(90,320,write_string,"./PNG/" + filename + ".png")
					write_cara(90,320,write_string,"spectrogram" + ".png")
				except:
					pass
			else:
				print "Error! " + filename + ".png is not found"
		if conf.get("file", "write_csv") == "on":
			if conf.get("analyze", "analyze") == "on":
				print "make csv"
				subprocess.Popen(["python", "./make_csv.py", "-c", filename])
		if conf.get("analyze", "analyze") == "on":
			print "make csv"
			subprocess.Popen(["python", "./make_csv.py", "-ac", filename])
		libhro.zip_write_dir("./echo", "echo.zip")
		libhro.zip_write_dir("./monoPNG", "monoPNG.zip")
		#img = Image.open(filename + ".png")
		#im = ImageDraw.ImageDraw(img)
		#im.rectangle((100, 100, 300, 300))
		#img.show()
	time.sleep(0.001)

==> Spec-Recorder%20Ver.1.31.zip: Spec-Recorder Ver.1.31/main.py <==
# -*- coding: utf-8 -*-
# Spec_Recoeder Ver.1.21
# License = MIT
# Author = Yuta Minakawa
import subprocess
import datetime
import time
import os
import ConfigParser
import libhro

try:
	import Image
	import ImageDraw
	import ImageFont
except ImportError:
	print "Error! PIL is not installed!"
	time.sleep(1000)
	exit()

high_color = 0
mono_color = 0
del_ogg = 0
write_filename = 0
write_csv = 0
oggfilename = ""
pngfilename = ""
analyze = 0
conf = ConfigParser.SafeConfigParser()
conf.read("./sr.conf")
if conf.get("server", "server") == "on":
	subprocess.Popen(["python", "server.py"])
	print "HTTP server is working"
else:
	print "HTTP server is unavailable"
	
if conf.get("file", "del_ogg") == "on":
	del_ogg = 1
	print "del_ogg is available"
else:
	print "del_ogg is unavailable"
	
if conf.get("file", "write_filename") == "on":
	write_filename = 1
	print "filename will be written"
else:
	print "filename will not be written"

if conf.get("file", "write_csv") == "on":
	write_csv = 1
	print "CSV file will be saved"
	
header = conf.get("file", "header") 
	
if conf.get("analyze", "analyze") == "on":
	analyze = 1
	print "data will be analyzed"
	
if os.name == 'posix':
	print "OS = Linux,BSD,etc"
if os.name == 'nt':
	print "OS = Windows"
	
def write_cara(x,y,string,filename):#画像ファイルへのファイル名の書き込み
	font = ImageFont.truetype("/usr/share/fonts/truetype/takao-gothic/TakaoGothic.ttf", 15, encoding="utf-8")
	img = Image.open(filename)
	draw = ImageDraw.Draw(img)
	draw.text((x,y), string, font=font, fill=255)
	img.save(filename)

def rec(filename):#It is not used.
	output = subprocess.call()
	return(output)
	
def how_long(filename):#OGGファイルの長さを調べる
	output = subprocess.check_output(["sox", "--info", "-d", filename])
	#print output
	minute = output[4]
	ten_second = output[6]
	second = output[7]
	file_info = (minute , ten_second, second)
	return(file_info)
	
def write2freq_exec(content):#使わない
	f = open('text.txt', 'w')
	f.write(content)
	f.close()
	
def spec(filename):#スペクトラム描画
	#output = subprocess.call(['sox', filename + ".ogg", "-n", 'rate', '3k',"spectrogram" , "-X", "8", "-Y", "300", "-o", filename + ".png" ])
	wq = ''
	oggfilename = wq + "./ogg/" + filename + ".ogg" + wq
	pngfilename = wq + "./PNG/" + filename + ".png" + wq
	monofilename = wq + "./monoPNG/" + filename + ".png" + wq
	output = subprocess.Popen(['sox', oggfilename[:], "-n", 'rate', '3k',"spectrogram" , "-X", "8", "-Y", "300", "-z", "100", "-o", pngfilename[:] ])
	print filename +".png" + " was made"
	subprocess.Popen(['sox', "./ogg/" + filename + ".ogg", "-n", 'rate', '3k',"spectrogram" , "-X", "8", "-Y", "300", "-z", "100"])
	output = subprocess.Popen(['sox', oggfilename[:], "-n", 'rate', '3k',"spectrogram" , "-X", "8", "-Y", "300", "-z", "100", "-m", "-o", monofilename[:] ])
	return(output)

print "Spec_Recorder Ver.1.21"

now_minute = int(datetime.datetime.now().strftime("%M"))
now_hour = int(datetime.datetime.now().strftime("%H"))
now_month = int(datetime.datetime.now().strftime("%m"))
now_day = int(datetime.datetime.now().strftime("%d"))
now_year = int(datetime.datetime.now().strftime("%Y"))

if int(datetime.datetime.now().strftime("%M")) % 5 == 0:
	time.sleep(60)
subprocess.Popen(["python", "./freq_exec.py", header])
print "Executed freq_exec.py"

if conf.get("mail", "mail") == "on":
	subprocess.Popen(["python", "./freq_send_mail.py"])
	print "executed freq_send_mail.py"

while 1==1:#メインループ
	if int(datetime.datetime.now().strftime("%M")) % 5 == 0:
		start_year = str(datetime.datetime.now().strftime("%Y"))[2:]
		start_month = str(datetime.datetime.now().strftime("%m"))[:]
		if start_month < 10:
			start_month = "0" + str(datetime.datetime.now().strftime("%m"))[:]
		start_day = str(datetime.datetime.now().strftime("%d"))[:]
		if start_day < 10:
			start_day = "0" + str(datetime.datetime.now().strftime("%d"))[:]
		start_hour = str(datetime.datetime.now().strftime("%H"))[:]
		if start_hour < 10:
			start_hour = "0" + str(datetime.datetime.now().strftime("%H"))[:]
		start_minute = str(datetime.datetime.now().strftime("%M"))[:]
		if datetime.datetime.now().strftime("%M") < 10:
			start_minute = "0" + str(datetime.datetime.now().strftime("%M"))[:]
		filename = header + str(start_year)[:] + str(start_month)[:] + str(start_day)[:] + str(start_hour)[:] + str(start_minute)[:]
		print "Audio fileneme is " + filename + ".ogg"
		print "Waiting 5 minutes"
		time.sleep(60)
		for cnt in range(10000):
			if os.path.exists("./ogg/" + filename + ".ogg") == 1:
				print 1
				if how_long("./ogg/"+ filename + ".ogg")[0] == "5":
					break
			#print "Waiting for " + filename +".ogg."
			#oggファイルを待つ
			time.sleep(10)
		try:
			libhro.spec(filename, False)
		except:
			pass
		if conf.get("file", "del_ogg") == "on":
			try:
				if os.name == 'nt':
					subprocess.call(["del", "./ogg/" + filename + ".ogg"])
				else:
					subprocess.call(["rm", "./ogg/" + filename + ".ogg"])
			except:
				print "can't delete OGGfile"
		for cnt in range(200):
			if os.path.exists("./monoPNG/" + filename + ".png") == 1:
				print filename + ".png is exist"
				break
			print "Waiting for " + filename +".png"
			time.sleep(0.5)
		if conf.get("file", "write_filename") == "on":
			if os.path.exists("./PNG/" + filename + ".png") == 1:
				try:
					write_string = filename[:]
					write_cara(90,320,write_string,"./PNG/" + filename + ".png")
					write_cara(90,320,write_string,"spectrogram" + ".png")
				except:
					pass
			else:
				print "Error! " + filename + ".png is not found"
		if conf.get("file", "write_csv") == "on":
			if conf.get("analyze", "analyze") == "off":
				print "make csv"
				subprocess.Popen(["python", "./make_csv.py", "-c", filename, header])
		if conf.get("analyze", "analyze") == "on":
			print "make csv"
			subprocess.Popen(["python", "./make_csv.py", "-ac", filename, header])
		if conf.get("file", "make_zip") == "on":
			print "make zip"
			libhro.zip_write_dir("./echo", "echo.zip")
			libhro.zip_write_dir("./monoPNG", "monoPNG.zip")
		#img = Image.open(filename + ".png")
		#im = ImageDraw.ImageDraw(img)
		#im.rectangle((100, 100, 300, 300))
		#img.show()
		start_minute = str(datetime.datetime.now().strftime("%M"))[:]
		if int(start_minute) >= 0 and int(start_minute) < 5 and conf.get("file", "auto_make_rmob") == "on":
			subprocess.Popen(["python", "./make_rmob.py", "all"])
	time.sleep(0.001)
